.. nodoctest

Factor complexity and Bispecial Extension Type
==============================================

.. automodule:: slabbe.bispecial_extension_type
   :members:
   :undoc-members:
   :show-inheritance:
   

